Learn R Programming

bayesDem (version 1.1-0)

bayesDem-package: Graphical User Interface for bayesTFR

Description

Provides Graphical user interface for the package bayesTFR.

Arguments

Details

ll{ Package: bayesDem Version: 1.1-0 Date: 2010-10-14 Depends: R (>= 2.9.0), cairoDevice, gWidgets, gWidgetsRGtk2, bayesTFR License: GPL (>= 2) URL: http://bayespop.csss.washington.edu }

The main function of the package is bayesDem.go which launches the GUI. It allows to run MCMCs and make probabilistic projections of total fertility rate (TFR) for all countries of the world, using a Bayesian hierarchical model and the United Nations demographic time series.

The GUI is organized into four tabs corresponding to the four main tasks: Running MCMCs, Continuing MCMCs, Making predictions, and Exploring results. Each of those tabs is again separated into tabs corresponding to usually one bayesTFR function. Each tab contains a Help button that shows the help file of the corresponding function, a Generate Script button that provides user with the corresponding bayesTFR command with argument values filled in from the GUI, and a button processing the function.

See Also

bayesTFR

Examples

Run this code
bayesDem.go()

Run the code above in your browser using DataLab