Learn R Programming

bayesDem (version 1.3-2)

bayesDem-package: Graphical User Interface for bayesTFR and bayesLife

Description

Provides Graphical user interface for the packages bayesTFR and bayesLife.

Arguments

Details

ll{ Package: bayesDem Version: 1.3-2 Date: 2011-10-20 Depends: R (>= 2.9.0), cairoDevice, gWidgets, gWidgetsRGtk2, bayesTFR, bayesLife License: GPL (>= 2) URL: http://bayespop.csss.washington.edu }

The main function of the package is bayesDem.go which launches the GUI. It allows to run MCMCs and make probabilistic projections of total fertility rate (TFR) and life expectancy (e0) for all countries of the world, using Bayesian hierarchical models and the United Nations demographic time series.

The GUI has two main tabs, one for estimating and predicting TFR, the other for estimating and predicting e0. Each of these two sections is organized into four tabs corresponding to the four main tasks: Running MCMCs, Continuing MCMCs, Making predictions, and Exploring results. Each of those tabs is again separated into tabs corresponding to usually one bayesTFR or bayesLife function. Each tab contains a Help button that shows the help file of the corresponding function, a Generate Script button that provides user with the corresponding bayesTFR/bayesLife command with argument values filled in from the GUI, and a button processing the function.

References

Hana Sevcikova, Leontine Alkema, Adrian E. Raftery (2011). bayesTFR: An R Package for Probabilistic Projections of the Total Fertility Rate. Journal of Statistical Software, 43(1), 1-29. http://www.jstatsoft.org/v43/i01/.

See Also

bayesTFR, bayesLife

Examples

Run this code
bayesDem.go()

Run the code above in your browser using DataLab