The main function of the package is bayesDem.go which launches the GUI. It allows to run MCMCs and make probabilistic projections of total fertility rate (TFR) and life expectancy (e0) for all countries of the world, using Bayesian hierarchical models and the United Nations demographic time series.
The GUI has two main tabs, one for estimating and predicting TFR, the other for estimating and predicting e0. Each of these two sections is organized into four tabs corresponding to the four main tasks: Running MCMCs, Continuing MCMCs, Making predictions, and Exploring results. Each of those tabs is again separated into tabs corresponding to usually one
bayesTFR, bayesLife