The main function of the package is bayesDem.go which launches the GUI. It allows to run MCMCs and make probabilistic projections of total fertility rate (TFR) and life expectancy (e0) for all countries of the world, using Bayesian hierarchical models and the United Nations demographic time series, as well as probabilistic projections of total population.
The GUI has three main tabs, one for estimating and predicting TFR, one for estimating and predicting e0, and one for projecting total population.
The first two sections are organized into four tabs corresponding to the four main tasks: Running MCMCs, Continuing MCMCs, Making predictions, and Exploring results. Each of those tabs is again separated into tabs corresponding to usually one
The third main section (for projecting total population) is separated into two tabs: One for generating predictions using given inputs, the other for exploring results. The user can generate population trajectories for given country, age and sex. In addition, probabilistic population pyramids can be also created from the GUI.
Hana Sevcikova, Leontine Alkema, Adrian E. Raftery (2011). bayesTFR: An
R Package for Probabilistic Projections of the Total Fertility Rate.
Journal of Statistical Software, 43(1), 1-29.
bayesTFR, bayesLife, bayesPop