bayesDem.go: Start Graphical User Interface for bayesTFR
Description
The function launches Graphical User Interface for the package bayesTFR.Usage
bayesDem.go(wpp.year = wpp.year.default)
Arguments
wpp.year
WPP year for which the GUI is started. Default is 2008. Note that the GUI will work only with values for which observed data are available in the bayesTFR package. Currently it is on