Learn R Programming

bayesDem (version 1.2-0)

bayesDem.go: Start Graphical User Interface for bayesTFR and bayesLife

Description

The function launches Graphical User Interface for the packages bayesTFR and bayesLife.

Usage

bayesDem.go(wpp.year = wpp.year.default)

Arguments

wpp.year
WPP year for which the GUI is started. Default is 2008. Note that the GUI will work only with values for which observed data are available in the two packages. Currently it is only 2008, see UN2008 and