Learn R Programming

bayesDem (version 2.2-1)

bayesDem.go: Start Graphical User Interface for bayesTFR and bayesLife

Description

The function launches Graphical User Interface for the packages bayesTFR and bayesLife.

Usage

bayesDem.go(wpp.year.tfr = tfr.wpp.year.default, 
    wpp.year.e0 = e0.wpp.year.default,
    wpp.year.pop = pop.wpp.year.default)

Arguments

wpp.year.tfr
WPP year used in the bayesTFR package. Default is 2010. Note that the GUI will work only with values for which observed data are available in the bayesTFR package. Currently it is 2010 and 2008, see UN2010
wpp.year.e0
WPP year used in the bayesLife package. Default is 2010. Currently years 2010 and 2008 are available, see UN2010e0.
wpp.year.pop
WPP year used in the bayesPop package. Default is 2010. Currently years 2010 and 2008 are available, see bayesPop.